Behaviors
==========

**How to create re-usable behaviors for Dexterity types**

.. toctree::
   :maxdepth: 2

   intro.rst
   behavior-basics.rst
   creating-and-registering-behaviors.rst
   providing-marker-interfaces.rst
   schema-only-behaviors.rst
   testing-behaviors.rst
